#
# spec file for package accerciser
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           accerciser
Version:        3.44.1
Release:        1.3
Summary:        Accessibility debugging tool
License:        BSD-3-Clause
Group:          Development/Tools/Other
URL:            https://wiki.gnome.org/Apps/Accerciser
Source0:        https://download.gnome.org/sources/accerciser/3.44/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  meson
BuildRequires:  pkgconfig
# py3atspi is a virtual name that is provided by the default at-spi stack
BuildRequires:  py3atspi
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(atspi-2) >= 2.5.2
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(pygobject-3.0) >= 2.90.3
# py3atspi is a virtual name that is provided by the default at-spi stack
Requires:       py3atspi
Requires:       python3-gobject-Gdk
Requires:       python3-python-xlib
BuildArch:      noarch

%description
Accerciser is an interactive Python accessibility explorer for the
GNOME desktop. It uses AT-SPI to inspect and control widgets, allowing
you to check if an application is providing correct information to
assistive technologies and automated test frameworks. Accerciser has a
simple plugin framework which you can use to create custom views of
accessibility information.

In essence, Accerciser is a next generation at-poke tool.

%package plugin-IPython
Summary:        Accessibility debugging tool - IPython console widget
Group:          Development/Tools/Other
Requires:       %{name} = %{version}
Requires:       python3-ipython
# we need setuptools for pkg_resources
Requires:       python3-setuptools
Supplements:    (%{name} and python3-ipython)

%description plugin-IPython
Accerciser is an interactive Python accessibility explorer for the
GNOME desktop.

This package provides the IPython console widget

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r -N "Accerciser" -G "Accesibility Debugger" accerciser Utility GNOME Accessibility
%find_lang %{name} %{?no_lang_C}
%python3_fix_shebang
%fdupes %{buildroot}%{_prefix}

%files
%license COPYING
%doc AUTHORS NEWS README.md
%doc %{_datadir}/help/C/%{name}/
%dir %{_datadir}/gnome-shell/
%dir %{_datadir}/gnome-shell/extensions/
%dir %{_datadir}/gnome-shell/extensions/accerciser@accerciser.gnome.org/
%{_datadir}/gnome-shell/extensions/accerciser@accerciser.gnome.org/extension.js
%{_datadir}/gnome-shell/extensions/accerciser@accerciser.gnome.org/metadata.json
%{_bindir}/%{name}
%{_datadir}/%{name}/
%exclude %{_datadir}/%{name}/plugins/ipython_view.py
%{_datadir}/metainfo/org.gtk.accerciser.metainfo.xml
%{_datadir}/glib-2.0/schemas/org.a11y.Accerciser.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1%{ext_man}
%{python3_sitelib}/%{name}/

%files plugin-IPython
%{_datadir}/%{name}/plugins/ipython_view.py

%files lang -f %{name}.lang

%changelog
* Mon Sep 30 2024 jun wang <jgwang@suse.com>
- Update to version 3.44.1
  * Replace intltool dep with gettext
  * Add meson build support
  * Drop autotools build
  * Add CI
  * plugins: Port from imp to importlib
  * Drop last occurrence of importing imp
  * Drop using deprecated gtk features
  * Don't add when cancelling "New Bookmark" dialog
  * event_monitor: Port "Clear Selection" button from "stock"
  * event_monitor: Fix saving to file
  * event_monitor: Fix jumping to object on click
  * node: Calculate screen coords for gtk4 apps
  * node: More reliably detect the right gtk4 window
  * Move retrieval of window stacking order to WindowManager
  * Only consider windows in current workspace for "Inspect under
    mouse"
  * WindowInfo: Add stacking order
  * WindowInfo: Add info whether on current workspace
  * Unify WindowManager implementations further, consider size
  * win manager: Add more infos to WindowInfo
  * window_manager: Extract helper method to get toolkit name and
    version
  * window_manager: Escape special chars in window title regex
  * Wnck: Use frame geometry when client geometry includes CSD
  * Support "Inspect under mouse" for Gtk 4 apps
  * GNOME: Use gtk and sandboxed app ID to retrieve app icon
  * GnomeShellWindowManager: Retrieve mouse pos from Mutter
  * GNOME Shell: Add extension and win manager using Mutter win pos
  * GNOME Shell: Add info whether on current workspace
  * GNOME Shell/Mutter: Use client/frame geometry except for GTK 3
  * GNOME Shell/Mutter: Support GNOME 47
  * GNOME Shell: Install the GNOME Shell extension
  * Add a window manager that retrieves screen coords from KWin
  * KWinWindowManager: Support KWin 6 as well
  * KWinWindowManager: Don't fail on win title containing quotes
  * KWinWindowManager: Get mouse position via KWin API
  * KWinWindowManager: Get window stacking order from KWin
  * KWin: Use 'console.info' instead of 'print' in KWin script
  * KWin 6: Use client/frame geometry instead of buffer geometry
    except for GTK 3
  * Kwin: Drop extra KWin 5 win title suffix right away
  * KWin: Retrieve app/window icon via desktop entry
  * interface_view: Add help text
  * interface_view: Update acc description when it changes
  * interface_view: Update help text when it changes
  * interface_view: Show infos for Hyperlink iface
  * ipython_view: Handle more color-related ANSI escape codes
  * ipython_view: Use raw string for regex
  * Add project_license tag to AppStream metadata file
  * Updated translations.
- Add meson BuildRequires and macros following upstreams port to it
* Sun Oct  8 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.42.0:
  + ipython_view:
  - Clear text after cursor on Ctrl+K
  - Copy selection to clipboard on Ctrl+C (Ctrl+Shift+c)
  - Fix off-by-one number in input prompt
  - Fix output with ipython3 8.5
  + interface_view:
  - Actually update value when it changes
  - Add TableCell interface
  - Handle exception when loading icon
  - Skip updating text that's already up-to-date
  + event_monitor: Drop hardcoded color
  + node: Drop unused Node#blinkRect and Xlib dependency
  + bookmarks: Use available dialog space for bookmark list
  + Force accerciser to run in X11 mode as required by libwnck
  + Require Gtk >= 3.24
  + Updated translations.
* Wed Oct  4 2023 Daniel Garcia <daniel.garcia@suse.com>
- call to %%python3_fix_shebang macro to use the right interpreter in
  the binary and not the link.
* Fri Jul 29 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.40.0:
  + ipython_view: Clear output on Ctrl+L.
  + Fix navigating to a bookmark when "View" -> "Show applications
    without children" is disabled (the default).
  + Make expanding and selecting the corresponding item in the
    treeview work when clicking on a bookmark for the first time.
  + Fix support for IPython 8.
  + Updated translations.
- Update Supplements to current openSUSE standard.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri Sep 11 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + No changes.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.1:
  + Remove some unused screenshots.
  + Fix indentation, buffer reset, autocompletion in IPython
    console.
  + Highlight region-changed events from screen reader.
  + Updated translations.
* Sun Aug  9 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + Updated translations.
* Sat Jul  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Updated translations.
* Sat Apr 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Fix python console with IPython 7.
  + Updated translations.
* Fri Mar  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Updated screenshots.
  + Updated translations.
* Wed Feb 12 2020 bjorn.lie@gmail.com
- Update to version 3.34.4:
  + Document new python-xlib dependency.
  + Updated translations.
- Add missing python3-python-xlib Requires.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Jan  1 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.3:
  + Updated translations.
* Thu Nov 21 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Updated translations.
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Updated translations.
* Sat Sep  7 2019 mgorse@suse.com
- Update to version 3.34.0:
  + No changes.
* Mon Sep  2 2019 mgorse@suse.com
- Update to version 3.33.92:
  + Add highlighting on text selection.
  + Updated translations.
* Fri Aug 30 2019 mgorse@suse.com
- Update to version 3.33.91:
  + Fix autoreconf dependency check
  + Updated translations.
- Changes from version 3.33.4:
  + Fix startup warnings
  + Fix some accessibleId access cases
  + Allow building with gettext ≥ 0.20
  + Show event sender
  + Fix auto-completion
  + On left arrow, go to parent before collapsing it
  + Use TreeModelFilter to filter the view
  + Let accerciser be selected, but do not refresh or highlight it
  + Hide applications without widgets by default
  + Updated translations.
- Changes from version 3.33.3:
  + Fix using translations
  + Fix some ui labelling
  + Fix showing relations
  + Use Unicode in translatable strings
  + Fix build instructions
  + Add expand/collapse node key handling
  + Don't crash on empty schema list
  + Better handle removed cursor row
  + Use fonts which explicitly show U+FFFC
  + Updated translations.
- Changes from version 3.33.2:
  + Restore preventing accerciser from exploring itself
  + Fix focus computation for ctrl-alt-b
  + Show accessible ID
- Changes from version 3.33.1:
  + help:
  - Fix broken Mallard markup for key combinations
  - Remove unhelpful Preferences screenshot
  + Use autoreconf instead deprecated gnome-autogen
  + Fix accessing items without a compositor
  + Preferences dialog: fix setting title
  + Fix warnings
  + Updated translations.
* Fri Jun 21 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.3:
  + Fix showing relations.
  + Fix support for IPython 7.
  + Fix build instructions.
  + Don't crash on empty schema list.
  + Fix using translations.
* Mon Jun  3 2019 Todd R <toddrme2178@gmail.com>
- Fix ipython package name.
* Fri May 17 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Fix using translations.
* Tue Apr  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Fix accessing items without a compositor.
  + Updated translations.
* Fri Mar 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated maintainers info.
  + Stopped using intltool.
  + Desktop: Dropped obsolete X-GNOME-Full-Name fields.
  + Updated bug reporting links.
  + Help: Replace git.gnome.org by gitlab.gnome.org.
  + Updated translations.
- Drop intltool BuildRequires, no longer needed.
* Sat Jan 12 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Updated maintainers info.
  + Fixed appdata file name.
  + Fixed duplicate section ID on help.
  + Marked missing string for translation.
  + Removed unused images from localized user docs accerciser.png.
  + ipython: Update to support IPython version 5 (bgo#776301).
  + Python 3.7+ support, async is a keyword.
  + Replace Bugzilla by Gitlab URL in DOAP file.
- Stop post(un) handling of glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un) + drop
  glib2_gsettings_schema_requires, no longer needed.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Sep 20 2016 dimstar@opensuse.org
- Update to version 3.22.0:
  + Added AppData file.
  + Better fix for bgo#709122.
  + Fix schema translations.
  + Provide a symbolic variant of the app icon.
  + Remove reference to icons/HighContrast/Makefile.
  + Preference dialog right resizable.
  + Bringing the rsvg-based highlight feature back.
  + Allow interface viewer states to fill horizontally.
  + Updated translations.
- No longer handle the HighContrast icon sets in post/postun.
* Tue May  3 2016 dimstar@opensuse.org
- Require python3-gobject-Gdk instead of python3-gobject: pygobject
  was further split in order to be able to install it without
  X-dependencies.
* Thu Apr 14 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Sun Apr 12 2015 zaitor@opensuse.org
- Drop IPython Requires from main package that was leftover on
  last change.
* Thu Mar 26 2015 dimstar@opensuse.org
- Replace pyatspi (Build)Requires with py3atspi: accerciser is
  a python3 application.
- Split out an accerciser-plugin-IPython package, providing the
  IPython console widget.
- Add python3-setuptools and pytho3-IPython Requires to
  accerciser-plugin-IPython: IPython-view plugin imports
  pkg_resources, which is part of setuptools and, as the name
  suggests, is based in IPython.
- Remove %%py_requires: it was python2 related and is since auto-
  detected.
- Change BuildArch to noarch: accerciser has no binary files.
* Tue Sep 23 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + No changes from previous version.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + doap: Update URLs, category apps and add
    <programming-language>.
  + Mark images as not translatable to keep them off translators
    radar.
  + Addressing some PyGObject initializer deprecations.
  + Adding transient windows for bookmarks dialogs.
  + Updated translations.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + User docs: Fixed a few broken/redirected links.
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92.1:
  + IPython View: Add backwards compatibility with old stable
    releases of IPython
- Changes from version 3.11.92:
  + Validate plugin: Make use of metaclasses compatible on python
    2.x & 3.x.
  + Interface Viewer plugin
  - Display of states should be wider.
  - Avoid the misalignement of elements when resizing.
  - Fix for bug 660971 - Fixing iv plugin's caret offset value.
  - Fix spinner on Value's section.
  + Macaroon
  - Make Macaroon work in Python 3.
  - Update get_text call according to latest API.
  - When recording, put right ATSPI roles in the output sequence.
  + Quick select: fix inspect accessible under mouse.
  + Updated translations.
* Mon Mar  3 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + ipython:
  - Update to match the latest IPython API.
  - seek to 0 after truncating stdout.
  - Adding auto-indentation.
  + bgo#723403: Save window's properties at 'delete-event' time.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + help: fix a typo.
  + Remove INSTALL from git repo.
  + Make the highlight window a POPUP window (bgo#709349).
  + Do not wrap __class__ object from plugins' methods
    (bgo#709122).
* Tue May 14 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Updated translations.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 zaitor@opensuse.org
- Update to version 3.7.92:
  + Add high contrast icon (bgo#695141).
  + Updated translations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Add keywords to the desktop file (bgo#687885).
  + Remove markup from translatable strings (bgo#692543).
  + Accerciser crash at launch because python3 gettext (bgo#694120)
  + Added some categories in the .desktop file for accerciser.
  + Fixed view manager's popup menu and translations.
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Bugs fixed: bgo#691136, bgo#691145, bgo#691147, bgo#691141.
- No longer pass --disable-scrollkeeper to configure: it's not
  valid since the port to the new documentation infrastructure.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Ported to Python3.
  + Modernized the autotools configuration.
  + Other changes:
  - Force accerciser to use Wnck 3.0 version.
  - Stop including the spec file for rpm packages.
* Mon Nov 12 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Force accerciser to use Wnck 3.0 version.
  + Updated translations.
- Add gobject-introspection BuildRequires: needed for the
  gi-dep-scanner/typelib() Requires.
- Drop the hack for removing en@shaw languages: we no longer build
  for openSUSE <= 12.2 anyway.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + help: fix link to gnome-help a11y help page.
  + help: adapt Galician and Spanish translations after link fix.
  + Updated translations.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Use yelp-tools instead of gnome-doc-utils
  + Updated translations.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams switch.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Do not check for 'toolkit-accessibility' gsettings key
  + Bump minimum version of Python to 2.7
  + Updated translations.
* Tue Aug  7 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Revert "Add a trailing underscore to identifiers which are
    Python keywords"
  + Upated translations.
* Tue Jun 26 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Add a trailing underscore to identifiers which are Python
    keywords
  + Remove markup from strings in .ui files
  + bgo#675989: Use python object attributes instead of gobject
    ones
  + bgo#674884: Use XDG base directory instead of $HOME
  + bgo#671179: Unexpected behaviours in ipython_view
  + bgo#671261: UnicodeDecodeError breaks the interface viewer
  + bgo#674166: Settings in wrong path
  + bgo#654418: Strings with context are not getting properly
    localized even though the translations have been provided
  + bgo#663777: WidgetHasText validator fails for widgets which
    don't need to implement getText()
  + bgo#678517: Macaroon script recorder is broken
  + Updated translations.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + bgo#673782: Accerciser does not fully load in F17
  + Updated translations.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 3.3.92:
  + bgo#671325: Fix unexpected behaviours in 'Hide/Show
    applications with <0 children' feature
  + Updated translations.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Add Option to filter out apps with 0 children
  + Update the ipython view plugin to the ipython v0.12 API (with
    ipython-0.11 backwards compatibility)
  + bgo#670415: Accerciser isn't explorable through the treeview
  + Updated translations.
* Fri Feb 17 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  No LGPL-2.1+ licenses found in package
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + bgo#659296: Fix incompatibilities with new version of IPython
  + Move macaroon to pygi.
  + Updated translations.
* Wed Oct 26 2011 dimstar@opensuse.org
- Updatet to version 3.3.1:
  + Updated translations.
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Updated translations.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Make maintiner mode enabled by default
  + bgo#658242: Need context for a proper translation
  + bgo#659425: Highlight is not working in fallback mode
  + Updated translations.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + bgo#657803: Missing part in pygi port
  + bgo#625902, bgo#658191: Port to GSettings
  + bgo#658196: Refresh node popup menu from accessible treeview
    isn't working
  + Updated translations.
- Drop gconf2-devel BuildRequires: it's not needed anymore with the
  port to GSettings.
- Replace GConf2 schemas handling with GSettings schemas handling,
  with %%glib2_gsettings_schema_* macros.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Ported from pygtk to gtk3 using gobject-based introspection
    bindings.
  + Updated translations.
- Remove python-gtk and python-wnck BuildRequires: they are not
  needed with the port to introspection-based bindings.
- Add pkgconfig(atspi-2), pkgconfig(gtk+-3.0),
  pkgconfig(pygobject-3.0) BuildRequires: new dependencies.
- Remove python-gconf, python-gnome, python-gtk,
  python-gtksourceview, python-rsvg, python-wnck Requires as
  accerciser has been ported to introspection-based bindings.
  However, add python-gobject Requires which is still clearly
  needed.
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Updated translations.
* Tue Jul 26 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + New mallard based-topic documentation.
  + Updated translations.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + bgo#653942: Remove script recorder references from POTFILES.in
  + bgo#650097: accerciser shows all text attributes in the same
    row
  + bgo#620705: help() in ipython console causes problems when
    accerciser is opened from a terminal
  + bgo#651557: Help button in the AT-SPI validator should link to
    english title's wiki sections
  + bgo#652610: Remove script recorder plugin
  + Updated translations.
* Mon Jun 13 2011 dimstar@opensuse.org
- Update to version 3.1.2:
  + bgo#641534: Pass a string when setting a tree view column
  + bgo#573845: Accerciser hangs interface on python exit
  + bgo#648150: 'Selected application' and 'Selected accessible'
    sources are ignored in event monitor
  + Accerciser now checks for toolkit-accessibility key using
    gsettings
  + Bumping Accerciser version to 3.x
  + Updated translations.
* Thu Jun  9 2011 vuntz@opensuse.org
- Update dependencies:
  + Change gnome-python-desktop BuildRequires to python-wnck, since
    only the wnck module is looked for.
  + Change gnome-python-desktop Requires to python-rsvg and
    python-wnck Requires.
  + Add missing python-gconf and python-gnome Requires.
* Tue Mar 15 2011 fcrozat@novell.com
- Remove unneed Requires on at-spi.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Oct 22 2010 vuntz@opensuse.org
- Update to version 1.12.1:
  + Updated translations.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 1.12.0:
  + Updated translations.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 1.11.1:
  + A fix for AT-SPI2 issues (bgo#617484)
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 1.10.1:
  + bgo#61457: Don't depend on widget name from GtkBuilder tree
* Wed Apr  7 2010 vuntz@opensuse.org
- BuildRequires and Requires pyatspi instead of python-atspi: this
  is a virtual name that is provided by the default at-spi stack,
  so we can easily switch between the stacks without having to
  change this package again.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 1.10.0:
  + AT-SPI2 support (considered experimental).
  + Updated translations.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 1.9.3:
  + Updated translations.
- Change at-spi BuildRequires and Requires to python-atspi, so we
  can use the new accessibility stack. We could depend on pyatspi
  (which is a virtual package that is provided by both python-atspi
  and python-atspi-corba), but this will make the build service not
  know what to do for the build.
* Mon Sep 28 2009 dimstar@opensuse.org
- Update to version 1.8.0:
  + bgo#593732 - Fixed crash when selecting item under pointer.
    Workaround for pygtk/gdk bug.
  + Updated translations.
* Tue Aug 25 2009 dimstar@opensuse.org
- Update to version 1.7.91:
  + bgo#592732 - Use correct Name and X-FullName in .desktop file
  + Updated translations.
* Fri Aug 14 2009 dominique-obs@leuenberger.net
- Update to version 1.7.90:
  + Updated translations.
* Wed Aug 12 2009 dominique-obs@leuenberger.net
- Define new python macros on openSUSE <= 11.1.
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Sun Jul 19 2009 dominique-obs@leuenberger.net
- Update to version 1.7.4:
  + Removed all libglade-related symbols
  + Updated translations.
* Wed May 27 2009 vuntz@novell.com
- Update to version 1.7.2:
  + Added accessible name changed listeners to update the view
    accordingly (bgo#582434).
  + Fixed editable text bug (bgo#574223).
  + Migrated to GtkBuilder from Glade.
* Tue May  5 2009 vuntz@novell.com
- Update to version 1.7.1:
  + Removed bonobo and ORBit references, in prep for GNOME 3.0 and
    D-Bus AT-SPI (bgo#580421).
  + Fixed IPython history behavior (bgo#578608).
  + Updated translations.
- Remove python-gnome, python-gnome-extras and python-orbit
  BuildRequires and Requires.
- Add python-gtk BuildRequires and Requires.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 1.6.1:
  + Fixed highlighting of an accessible on the desktop when it is
    selected in Accerciser (aka node highlighting). (bgo#576756).
  + Updated translations.
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 1.6.0:
  + Fixed selection interface in interface viewer plugin
    (bgo#574783).
  + Added an informative window title (bgo#574103).
  + Fixed empty padding issue in prefs dialog (bgo#574101).
  + Ported script recorder to gtksourceview2 (bgo#574100).
  + Don't allow the set_range to change the value of our accessible
    (bgo#572201).
  + Updated translations.
- Remove unneeded BuildRequires: gnome-common, gtk2-devel,
  libgnome-devel, libgnomeui-devel, pkg-config, scrollkeeper
- Add python-gtksourceview Requires.
- Add py_requires.
- Remove AutoReqProv: it's default now.
- Remove definition of CFLAGS.
- Drop autoreconf call.
- Don't package omf files twice (they are in the lang package too).
- Clean up file list.
* Fri Feb 20 2009 vuntz@novell.com
- Review changes.
* Thu Feb 19 2009 dominique-obs@leuenberger.net
- Update to version 1.5.91:
  + Provide a $srcdir (bgo#570332).
  + Don't use _() in i18n.py.
  + Updated translations.
* Wed Feb  4 2009 stshaw@novell.com
- Update to version 1.5.9:
  + Bugs fixed: bgo#569341, bgo#520296, bgo#547778, bgo#563284,
    bgo#564776, bgo#561598, bgo#520296, bgo#555416, bgo#555108
  + Use gettext.gettext (imported as translate_func) instead of _
    in C_ to avoid distcheck failure.
  + Import markup_escape_text from gobject instead of glib. This
    seems to work more consistently across distros.
  + src/lib/accerciser/node.py: If duration is 0, don't highlight
    at all.
  + When a node is updated to desktop, don't highlight the entire
    desktop, it get's annoying.
  + Disable event monitoring if the event we are listening for
    disappears.
  + Catch exceptions when getting states during state changes, they
    could be defunct state, which means the object is dead.
* Tue Nov 25 2008 stshaw@novell.com
- update to 1.4.0:
  * Bugs fixed: bgo#550689, bgo#547778
* Tue Sep  9 2008 ro@suse.de
- use macro py_sitedir in filelist
* Thu Aug 14 2008 stshaw@novell.com
- Update to 1.3.6:
  * Bugs fixed: bgo#545904, bgo#528828, bgo#540166, bgo#520296,
    bgo#503654, bgo#494634, bgo#494632, bgo#493650, bgo#528261,
    bgo#509805, bgo#508665, bgo#500900, bgo#431882, bgo#469427
  * src/lib/accerciser/node.py:
    Fixed highlighting in composited environments.
  * pyreqs.py:
    Changed pyatspi version checking to use the new
    __version__ symbol.
    Check that the version of pyatspi is current enough.
  * plugins/quick_select.py:
    Make it work better with tab lists and windows.
  * plugins/interface_view.py:
    Removed prefix space from
  * src/lib/accerciser/pyatspi.zip:
    Deleted.
  * src/lib/accerciser/accerciser.py:
    Make event handling asynchronous.
  * plugins/event_monitor.py:
    Remove decoupling of event handling, we don't need to worry
    about it any more.
    Added a new global hotkey for starting/stopping recording.
  * plugins/validate.py:
    Removed Save button stuff.
  * plugins/validate.glade:
    Removed Save button, changed layout so it won't be so wide.
    Added label relationships to comobox and label.
  * plugindata/validate/basic.py:
    Old code for validate plugin
  * plugindata/validate/Makefile.am:
    Fixed install path.
  * plugins/ipython_view.py (IPythonView.__init__):
    Removed a "print".
  * plugins/ipython_view.py (ConsoleView):
    De-coupled all caret movement and text manipulation in the
    ConsoleView from the input event handling. Without decoupling
    we get a lockup if threading is enabled when a GAIL callback
    tries to acquire the lock during a GDK event dispatch.
  * Updated translations.
* Mon Mar  3 2008 hpj@suse.de
- Initial package.
